@@ -1,5 +1,5 @@
 package Net::Async::Webservice::DHL::Types;
-$Net::Async::Webservice::DHL::Types::VERSION = '0.001';
+$Net::Async::Webservice::DHL::Types::VERSION = '1.0.0';
 {
   $Net::Async::Webservice::DHL::Types::DIST = 'Net-Async-Webservice-DHL';
 }
@@ -7,7 +7,7 @@ use strict;
 use warnings;
 use Type::Library
     -base,
-    -declare => qw( Address RouteType CountryCode RegionCode );
+    -declare => qw( Address );
 use Type::Utils -all;
 use Types::Standard -types;
 use namespace::autoclean;
@@ -17,12 +17,6 @@ use namespace::autoclean;
 
 class_type Address, { class => 'Net::Async::Webservice::DHL::Address' };
 
-enum RouteType, [qw(O D)];
-
-declare CountryCode, as Str, where { length($_) == 2 };
-
-enum RegionCode, [qw(AP EU AM)];
-
 1;
 
 __END__
@@ -37,7 +31,7 @@ Net::Async::Webservice::DHL::Types - type library for DHL
 
 =head1 VERSION
 
-version 0.001
+version 1.0.0
 
 =head1 DESCRIPTION
 
